@@ -23,14 +23,18 @@ def delete_user_data_structure():
     logger.info("Checking Old UserDataStructures")
     try:
         user_data_structure_perm = UserDataStructure.get_permission()
-        for data_structure_element in system_api.get_all_data_structure_elements():
+        for (
+            data_structure_element
+        ) in system_api.get_all_data_structure_elements():
             if (
                 data_structure_element.data_structure
                 and data_structure_element.data_structure.get_object_permission()
                 == user_data_structure_perm
             ):
-                if data_structure_element.creation_date < timezone.now() - timedelta(
-                    hours=USER_DATA_STRUCTURE_HOURS_THRESHOLD
+                if (
+                    data_structure_element.creation_date
+                    < timezone.now()
+                    - timedelta(hours=USER_DATA_STRUCTURE_HOURS_THRESHOLD)
                 ):
                     data_structure_element.delete()
         logger.info("FINISH checking DataStructures.")
