@@ -4,6 +4,7 @@ from django.contrib.admin.views.decorators import staff_member_required
 from django.http.response import HttpResponseBadRequest, HttpResponse
 from rest_framework.permissions import IsAuthenticated
 
+from core_main_app.components.version_manager import api as version_manager_api
 from core_main_app.rest.template_version_manager.abstract_views import (
     AbstractStatusTemplateVersion,
 )
@@ -29,7 +30,7 @@ class CurrentTemplateVersion(AbstractStatusTemplateVersion):
 
             TemplateVersion
         """
-        return user_version_manager_api.set_current(
+        return version_manager_api.set_current(
             template_object, request=self.request
         )
 
@@ -46,8 +47,12 @@ def set_current_template_version_from_version_manager(request):
     """
     try:
 
-        user_version_manager_api.set_default_version_manager(request.GET["id"], request)
+        user_version_manager_api.set_default_version_manager(
+            request.GET["id"], request
+        )
     except Exception as e:
-        return HttpResponseBadRequest(str(e), content_type="application/javascript")
+        return HttpResponseBadRequest(
+            str(e), content_type="application/javascript"
+        )
 
     return HttpResponse(content_type="application/javascript")
