@@ -2,7 +2,9 @@
 """
 from core_main_app.components.data.models import Data
 from core_main_app.components.template.models import Template
-from core_main_app.utils.integration_tests.fixture_interface import FixtureInterface
+from core_main_app.utils.integration_tests.fixture_interface import (
+    FixtureInterface,
+)
 from core_user_registration_app.components.user_data_structure.models import (
     UserDataStructure,
 )
@@ -37,20 +39,30 @@ class UserDataStructureFixtures(FixtureInterface):
 
         # NOTE: no xml_content to avoid using unsupported GridFS mock
         self.data = Data(
-            template=self.template, user_id="1", dict_content=None, title="title"
-        ).save()
+            template=self.template,
+            user_id="1",
+            dict_content=None,
+            title="title",
+        )
+        self.data.save()
 
         self.data_structure_1 = UserDataStructure(
-            user="1", template=self.template, name="data_structure_1", data=self.data
-        ).save()
+            user="1",
+            template=self.template,
+            name="data_structure_1",
+            data=self.data,
+        )
+        self.data_structure_1.save()
 
         self.data_structure_2 = UserDataStructure(
             user="1", template=self.template, name="data_structure_2"
-        ).save()
+        )
+        self.data_structure_2.save()
 
         self.data_structure_3 = UserDataStructure(
             user="2", template=self.template, name="data_structure_3"
-        ).save()
+        )
+        self.data_structure_3.save()
 
         self.data_collection = [
             self.data_structure_1,
@@ -65,12 +77,12 @@ class UserDataStructureFixtures(FixtureInterface):
         Returns:
 
         """
-        template = Template()
+        self.template = Template()
         xsd = (
             '<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">'
             '<xs:element name="tag"></xs:element></xs:schema>'
         )
-        template.content = xsd
-        template.hash = ""
-        template.filename = "filename"
-        self.template = template.save()
+        self.template.content = xsd
+        self.template.hash = ""
+        self.template.filename = "filename"
+        self.template.save()
